@@ -11,7 +11,7 @@ class init_anim:
         
         self.speed_up = speed_up
         
-        self.frames = np.linspace(1, int(t[-1]*self.frame_rate/speed_up), len(t)).astype(int)
+        self.frames = np.linspace(1, int(t[-1]*self.frame_rate/speed_up+1), len(t)).astype(int)
         
         self.frame_duration = self.frames[-1]
 
